from random import randint

class guess():
    
    def start(guess, range=None):

        if range is None:
            range = '1-10'

        if not '-' in range:
            return print('You did not enter the right format'), None

        range = str(range)

        fr, to = range.split('-')

        guess = int(guess)
        number = randint(int(fr),int(to))

        if guess == number:
            return guess, True
        elif not guess == number:
            return guess, False



"""
Python-Games package
"""

__author__ = 'Kevys'
__license__ = 'MIT'
__version__ = '1.0.0'
__description__ = 'A python package with different games'

from .guess import *
from .rps import *

guess = guess.start
rps = rps.start


from random import randint

class rps():

    def start(choice):

        if choice is None:
            return("You didn't choose rock, paper or scissor")

        choice = choice.lower()

        if choice == 'rock':
            number = 1
        elif choice == 'paper':
            number = 2
        elif choice == 'scissor':
            number = 3

        ai = randint(1,3)

        if ai == 1:
            picked = 'rock'
        elif ai == 2:
            picked = 'paper'
        elif ai == 3:
            picked = 'scissor'

        if number == ai:
            return print(f"You both choose {choice}"), None

        elif number == 3 and ai == 1:
            return choice, picked, False
        elif number == 1 and ai == 2:
            return choice, picked, False
        elif number == 2 and ai == 3:
            return choice, picked, False
        
        elif number == 1 and ai == 3:
            return choice, picked, True
        elif number == 2 and ai == 1:
            return choice, picked, True
        elif number == 3 and ai == 2:
            return choice, picked, True


from setuptools import setup

import games

author = games.__author__
license = games.__license__
version = games.__version__
description = games.__description__

with open('README.md') as f:
    README = f.read()

packages = [
    'games',
]

setup(
    name='python-games',
    author=author,
    url='https://github.com/kevys/python-games',
    project_urls={"Issues": "https://github.com/kevys/python-games/issues"},
    version=version,
    packages=packages,
    license=license,
    description=description,
    long_description=README,
    long_description_content_type="text/markdown",
    include_package_data=True,
    python_requires='>=3.8.0',
    keywords=['python'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ]
)